@@ -1,3 +1,3 @@
 (function() {var implementors = {};
-implementors["alloc"] = [{"text":"impl&lt;F:&nbsp;?Sized + Future + Unpin&gt; Future for Box&lt;F&gt;","synthetic":false,"types":[]}];
+implementors["alloc"] = [{"text":"impl&lt;F:&nbsp;?Sized + Future + Unpin, A:&nbsp;AllocRef&gt; Future for Box&lt;F, A&gt;","synthetic":false,"types":[]}];
 if (window.register_implementors) {window.register_implementors(implementors);} else {window.pending_implementors = implementors;}})()
\ No newline at end of file
